import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:natinfo_flutter/config/app_config.dart';
import 'package:natinfo_flutter/providers/theme_provider.dart';
import 'repositories/natinf_repository.dart';
import 'pages/data_initialization_screen.dart';

void main() async {
  WidgetsFlutterBinding.ensureInitialized();
  final repository = NatinfRepository();
  await repository.init();
  runApp(MyApp(repository: repository));
}

class MyApp extends StatelessWidget {
  final NatinfRepository repository;
  const MyApp({super.key, required this.repository});

  @override
  Widget build(BuildContext context) {
    return MultiProvider(
      providers: [
        Provider<NatinfRepository>.value(value: repository),
        ChangeNotifierProvider(create: (_) => ThemeProvider()),
      ],
      child: Consumer<ThemeProvider>(
        builder: (context, themeProvider, child) {
          return MaterialApp(
            title: 'NATINFo',
            theme: ThemeData.light().copyWith(
              primaryColor: themeProvider.primaryColor,
              appBarTheme: AppBarTheme(
                color: themeProvider.primaryColor,
                foregroundColor: themeProvider.primaryTextColor,
              ),
            ),
            darkTheme: ThemeData.dark().copyWith(
              primaryColor: themeProvider.primaryColor,
              appBarTheme: AppBarTheme(
                color: themeProvider.primaryColor,
                foregroundColor: themeProvider.primaryTextColor,
              ),
            ),
            themeMode: themeProvider.isDarkMode ? ThemeMode.dark : ThemeMode.light,
            home: DataInitializationScreen(repository: repository),
          );
        },
      ),
    );
  }
}